<?php

namespace Luticate\Auth\Business;

use Illuminate\Http\Request;
use Luticate\Utils\LuBusiness;
use Luticate\Auth\DataAccess\LuticateUsersDataAccess;
use Luticate\Auth\DBO\LuticateUsersDbo;
use Luticate\Utils\LuRoute;

class LuticateUsersBusiness extends LuBusiness {
    /**
     * @var LuticateUsersDbo
     */
    private static $_currentUser;

    const TOKEN_HEADER = "X-Authentication";

    public function __construct()
    {
        $this->dataAccess = new LuticateUsersDataAccess();
    }

    public static function getCurrentUser()
    {
        return self::$_currentUser;
    }

    /**
     * @param $permissions string[]
     * @param $request Request
     * @return bool
     */
    public static function authFilter($permissions, $request)
    {
        $token = $request->header(self::TOKEN_HEADER);
        if ($token == null)
        {
            return false;
        }
        $data = JwtHelper::decode($token);
        if ($data == null)
        {
            return false;
        }
        $user_id = $data[JwtHelper::USER_KEY];

        foreach ($permissions as $permission) {
            if (!LuticatePermissionsBusiness::getUserPermission($user_id, $permission)) {
                return false;
            }
        }

        $user = LuticateUsersBusiness::getById($user_id);
        if ($user == null)
        {
            return false;
        }
        self::$_currentUser = $user;
        return true;
    }
}